==> kdenlive-19.03.80.tar.xz: kdenlive-19.03.80/src/dialogs/splash.hpp <==
/***************************************************************************
 *   Copyright (C) 2017 by Nicolas Carion                                  *
 *   This file is part of Kdenlive. See www.kdenlive.org.                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3 or any later version accepted by the       *
 *   membership of KDE e.V. (or its successor approved  by the membership  *
 *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
 *   version 3 of the license.                                             *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef SPLASH_H
#define SPLASH_H

#include <QObject>

class QQmlEngine;

class Splash : public QObject
{
    Q_OBJECT

public:
    Splash();
    ~Splash();

    void endSplash();

signals:
    void sigEndSplash();

protected:
    QQmlEngine *m_engine;
};

#endif

==> kdenlive-19.12.2.tar.xz: kdenlive-19.12.2/src/dialogs/splash.hpp <==
/***************************************************************************
 *   Copyright (C) 2017 by Nicolas Carion                                  *
 *   This file is part of Kdenlive. See www.kdenlive.org.                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3 or any later version accepted by the       *
 *   membership of KDE e.V. (or its successor approved  by the membership  *
 *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
 *   version 3 of the license.                                             *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef SPLASH_H
#define SPLASH_H

#include <QObject>
#include <memory>

class QQmlEngine;
class QQmlComponent;
class QQuickWindow;

class Splash : public QObject
{
    Q_OBJECT

public:
    Splash(QObject *parent);
    ~Splash();

    void endSplash();

signals:
    void sigEndSplash();

private slots:
    void continueLoading();

protected:
    QQmlEngine *m_engine;
    QQmlComponent* component;
    QQuickWindow *childItem;
};

#endif
